@@ -1,13 +1,14 @@
-from typing import Generator
-import click
 import datetime
-import dateutil.parser
 import json
 import sys
+from typing import Generator
+
+import click
+import dateutil.parser
 
-from . import launchable
-from ..testpath import TestPath, parse_test_path, unparse_test_path
 from ..commands.record.case_event import CaseEvent, CaseEventType
+from ..testpath import TestPath, parse_test_path, unparse_test_path
+from . import launchable
 
 
 @click.argument('test_path_file', required=True, type=click.File('r'))
@@ -117,13 +118,11 @@ def record_tests(client, test_result_file):
         default_created_at = datetime.datetime.now(
             datetime.timezone.utc).isoformat()
         for case in doc['testCases']:
-            test_path = case['testPath']
+            test_path = parse_test_path(case['testPath'])
             status = case['status']
             duration_secs = case['duration'] or 0
             created_at = case['createdAt'] or default_created_at
 
-            # Validation
-            parse_test_path(test_path)
             if status not in CaseEvent.STATUS_MAP:
                 raise ValueError(
                     "The status of {} should be one of {} (was {})".format(
