@@ -7,9 +7,9 @@ import types
 import unittest
 
 import click.testing
+import responses  # type: ignore
 from click.testing import CliRunner
 
-import responses  # type: ignore
 from launchable.__main__ import main
 from launchable.utils.http_client import get_base_url
 from launchable.utils.session import SESSION_DIR_KEY, clean_session_files
@@ -88,6 +88,19 @@ class CliTestCase(unittest.TestCase):
                 self.session_id),
             json=[],
             status=200)
+        responses.add(
+            responses.GET,
+            "{}/intake/organizations/{}/workspaces/{}/builds/{}/test_sessions/{}".format(
+                get_base_url(),
+                self.organization,
+                self.workspace,
+                self.build_name,
+                self.session_id),
+            json={
+                'id': self.session_id,
+                'isObservation': False,
+            },
+            status=200)
         responses.add(
             responses.PATCH,
             "{}/intake/organizations/{}/workspaces/{}/builds/{}/test_sessions/{}/close".format(
